from setuptools import setup

setup(
      name = 'ventura',
      version = '0.2',
      description = 'Simple xml-based updater in python 3.6 with no try-catch statement',
      url = 'http://github.com/hermespasser/ventura',
      author = 'Hermes Passer',
      author_email = 'hermespasser@gmail.com',
      license = 'MIT',
      packages = ['ventura']
)
